@@ -10,7 +10,7 @@ use warnings;
 use feature qw( switch );
 no if $] >= 5.017011, warnings => 'experimental::smartmatch';
 
-our $VERSION = '0.23';
+our $VERSION = '0.24';
 
 use Carp;
 use Scalar::Util qw( weaken );
@@ -364,7 +364,7 @@ boolean true and false. They are
 
 package Devel::MAT::SV::Immortal;
 use base qw( Devel::MAT::SV );
-our $VERSION = '0.23';
+our $VERSION = '0.24';
 use constant immortal => 1;
 sub new {
    my $class = shift;
@@ -377,13 +377,13 @@ sub _outrefs { () }
 
 package Devel::MAT::SV::UNDEF;
 use base qw( Devel::MAT::SV::Immortal );
-our $VERSION = '0.23';
+our $VERSION = '0.24';
 sub desc { "UNDEF" }
 sub type { "UNDEF" }
 
 package Devel::MAT::SV::YES;
 use base qw( Devel::MAT::SV::Immortal );
-our $VERSION = '0.23';
+our $VERSION = '0.24';
 sub desc { "YES" }
 sub type { "SCALAR" }
 
@@ -398,7 +398,7 @@ sub name {}
 
 package Devel::MAT::SV::NO;
 use base qw( Devel::MAT::SV::Immortal );
-our $VERSION = '0.23';
+our $VERSION = '0.24';
 sub desc { "NO" }
 sub type { "SCALAR" }
 
@@ -413,7 +413,7 @@ sub name {}
 
 package Devel::MAT::SV::Unknown;
 use base qw( Devel::MAT::SV );
-our $VERSION = '0.23';
+our $VERSION = '0.24';
 __PACKAGE__->register_type( 0xff );
 
 sub desc { "UNKNOWN" }
@@ -422,7 +422,7 @@ sub _outrefs {}
 
 package Devel::MAT::SV::GLOB;
 use base qw( Devel::MAT::SV );
-our $VERSION = '0.23';
+our $VERSION = '0.24';
 __PACKAGE__->register_type( 1 );
 
 =head1 Devel::MAT::SV::GLOB
@@ -575,7 +575,7 @@ sub _outrefs
 
 package Devel::MAT::SV::SCALAR;
 use base qw( Devel::MAT::SV );
-our $VERSION = '0.23';
+our $VERSION = '0.24';
 __PACKAGE__->register_type( 2 );
 
 =head1 Devel::MAT::SV::SCALAR
@@ -729,7 +729,7 @@ sub _outrefs
 
 package Devel::MAT::SV::REF;
 use base qw( Devel::MAT::SV );
-our $VERSION = '0.23';
+our $VERSION = '0.24';
 __PACKAGE__->register_type( 3 );
 
 =head1 Devel::MAT::SV::REF
@@ -806,7 +806,7 @@ sub _outrefs
 
 package Devel::MAT::SV::ARRAY;
 use base qw( Devel::MAT::SV );
-our $VERSION = '0.23';
+our $VERSION = '0.24';
 __PACKAGE__->register_type( 4 );
 
 =head1 Devel::MAT::SV::ARRAY
@@ -926,7 +926,7 @@ sub _outrefs
 package Devel::MAT::SV::PADLIST;
 # Synthetic type
 use base qw( Devel::MAT::SV::ARRAY );
-our $VERSION = '0.23';
+our $VERSION = '0.24';
 use constant type => "PADLIST";
 
 =head1 Devel::MAT::SV::PADLIST
@@ -962,7 +962,7 @@ sub _outrefs
 package Devel::MAT::SV::PADNAMES;
 # Synthetic type
 use base qw( Devel::MAT::SV::ARRAY );
-our $VERSION = '0.23';
+our $VERSION = '0.24';
 use constant type => "PADNAMES";
 
 =head1 Devel::MAT::SV::PADNAMES
@@ -1038,7 +1038,7 @@ sub _outrefs
 package Devel::MAT::SV::PAD;
 # Synthetic type
 use base qw( Devel::MAT::SV::ARRAY );
-our $VERSION = '0.23';
+our $VERSION = '0.24';
 use constant type => "PAD";
 
 use List::Util qw( pairmap );
@@ -1099,7 +1099,7 @@ sub _outrefs
 
 package Devel::MAT::SV::HASH;
 use base qw( Devel::MAT::SV );
-our $VERSION = '0.23';
+our $VERSION = '0.24';
 __PACKAGE__->register_type( 5 );
 
 =head1 Devel::MAT::SV::HASH
@@ -1229,7 +1229,7 @@ sub _outrefs
 
 package Devel::MAT::SV::STASH;
 use base qw( Devel::MAT::SV::HASH );
-our $VERSION = '0.23';
+our $VERSION = '0.24';
 __PACKAGE__->register_type( 6 );
 
 =head1 Devel::MAT::SV::STASH
@@ -1349,7 +1349,7 @@ sub _outrefs
 
 package Devel::MAT::SV::CODE;
 use base qw( Devel::MAT::SV );
-our $VERSION = '0.23';
+our $VERSION = '0.24';
 __PACKAGE__->register_type( 7 );
 
 use Carp;
@@ -1793,18 +1793,45 @@ sub _outrefs
 
 package Devel::MAT::SV::IO;
 use base qw( Devel::MAT::SV );
-our $VERSION = '0.23';
+our $VERSION = '0.24';
 __PACKAGE__->register_type( 8 );
 
+=head1 Devel::MAT::SV::IO
+
+Represents an IO handle; an SV type of C<SVt_PVIO>.
+
+=cut
+
 sub load
 {
    my $self = shift;
    my ( $header, $ptrs, $strs ) = @_;
+   my $df = $self->df;
+
+   @{$self}{qw( ifileno ofileno )} =
+      unpack "$df->{uint_fmt}2", $header;
+
+   $_ == $df->{minus_1} and $_ = -1 for @{$self}{qw( ifileno ofileno )};
 
    @{$self}{qw( topgv_at formatgv_at bottomgv_at )} =
       @$ptrs;
 }
 
+=head2 ifileno
+
+=head2 ofileno
+
+   $ifileno = $io->ifileno
+
+   $ofileno = $io->ofileno
+
+Returns the input or output file numbers.
+
+=cut
+
+sub ifileno { my $self = shift; return $self->{ifileno} }
+sub ofileno { my $self = shift; return $self->{ofileno} }
+
 sub topgv    { my $self = shift; $self->df->sv_at( $self->{topgv_at}    ) }
 sub formatgv { my $self = shift; $self->df->sv_at( $self->{formatgv_at} ) }
 sub bottomgv { my $self = shift; $self->df->sv_at( $self->{bottomgv_at} ) }
@@ -1823,7 +1850,7 @@ sub _outrefs
 
 package Devel::MAT::SV::LVALUE;
 use base qw( Devel::MAT::SV );
-our $VERSION = '0.23';
+our $VERSION = '0.24';
 __PACKAGE__->register_type( 9 );
 
 sub load
@@ -1856,7 +1883,7 @@ sub _outrefs
 
 package Devel::MAT::SV::REGEXP;
 use base qw( Devel::MAT::SV );
-our $VERSION = '0.23';
+our $VERSION = '0.24';
 __PACKAGE__->register_type( 10 );
 
 sub load {}
@@ -1867,7 +1894,7 @@ sub _outrefs { () }
 
 package Devel::MAT::SV::FORMAT;
 use base qw( Devel::MAT::SV );
-our $VERSION = '0.23';
+our $VERSION = '0.24';
 __PACKAGE__->register_type( 11 );
 
 sub load {}
@@ -1878,7 +1905,7 @@ sub _outrefs { () }
 
 package Devel::MAT::SV::INVLIST;
 use base qw( Devel::MAT::SV );
-our $VERSION = '0.23';
+our $VERSION = '0.24';
 __PACKAGE__->register_type( 12 );
 
 sub load {}
