@@ -8,7 +8,7 @@ package Devel::MAT::Tool::Count;
 use strict;
 use warnings;
 
-our $VERSION = '0.23';
+our $VERSION = '0.24';
 
 use constant CMD => "count";
 
@@ -66,6 +66,19 @@ sub count_svs
    return \%kinds, \%blessed_kinds;
 }
 
+=head1 COMMANDS
+
+=head2 count
+
+   pmat> count
+     Kind                 Count      (blessed) 
+     ARRAY                134                  
+     CODE                 133                  
+
+Prints a summary of the count of each type of object.
+
+=cut
+
 sub run_cmd
 {
    my $self = shift;
